@@ -633,6 +633,15 @@ class CausalTree:
 
             unique_treatment = unique_treatment[first_quartile:third_quartile]
 
+        if self.max_values < 1:
+            idx = np.round(np.linspace(
+                0, len(unique_treatment) - 1, self.max_values * len(unique_treatment))).astype(int)
+            unique_treatment = unique_treatment[idx]
+        else:
+            idx = np.round(np.linspace(
+                0, len(unique_treatment) - 1, self.max_values)).astype(int)
+            unique_treatment = unique_treatment[idx]
+
         yyt = np.tile(train_outcome, (unique_treatment.shape[0], 1))
         ttt = np.tile(train_treatment, (unique_treatment.shape[0], 1))
         yyv = np.tile(val_outcome, (unique_treatment.shape[0], 1))
